translate.convert.csv2tbx

Package translate :: Package convert :: Module csv2tbx |
[hide private]
[frames] | no frames]

# Module csv2tbx

source code

convert Comma-Separated Value (.csv) files to a TermBase eXchange (.tbx) glossary file

Classes | [hide private]
| csv2tbx a class that takes translations from a .csv file and puts them in a .tbx file

Functions | [hide private]
convertcsv(inputfile, outputfile, templatefile, charset=None, columnorder=None) reads in inputfile using csvl10n, converts using csv2tbx, writes to outputfile | source code
main() | source code

Imports: tbx, csvl10n